"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateRepoConfig = exports.readRcConfig = void 0;
const file_1 = require("../utils/file");
const format_code_1 = require("../utils/format-code");
const loggin_1 = require("../../core/loggin");
const rc_1 = require("../../core/options/rc");
function readRcConfig(cfgPath = '') {
    const configPath = cfgPath || (0, rc_1.get)();
    const repoConfigFile = (0, file_1.readFile)(configPath) || '{}';
    (0, loggin_1.logVerbose)('readRcConfig:', configPath, JSON.parse(repoConfigFile));
    return JSON.parse(repoConfigFile);
}
exports.readRcConfig = readRcConfig;
function updateRepoConfig(config, cfgPath = '') {
    const configPath = cfgPath || (0, rc_1.get)();
    (0, loggin_1.logVerbose)(`Update config under ${configPath}`);
    // NOTICE: this is needed for better git flow.
    // Touch a file only if needed
    if (JSON.stringify(readRcConfig()) !== JSON.stringify(config)) {
        (0, file_1.writeFile)(configPath, (0, format_code_1.formatCode)(JSON.stringify(config), 'json'));
        (0, loggin_1.logVerbose)(`New config ${JSON.stringify(config)}`);
    }
    else {
        (0, loggin_1.logVerbose)(`No updates for ${configPath} to save.`);
    }
}
exports.updateRepoConfig = updateRepoConfig;
//# sourceMappingURL=config.js.map