"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureFormat = exports.ensureUrl = exports.ensureUfPath = exports.ensureOutPath = void 0;
const tslib_1 = require("tslib");
const interactive_1 = require("../../core/options/interactive");
const constants_1 = require("./constants");
const enquirer_1 = require("enquirer");
const constats_1 = require("../../commands/collect/constats");
const fs_1 = require("fs");
function ensureOutPath(config) {
    var _a, _b;
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let suggestion = ((_a = config === null || config === void 0 ? void 0 : config.persist) === null || _a === void 0 ? void 0 : _a.outPath) || constants_1.DEFAULT_PERSIST_OUT_PATH;
        if ((0, interactive_1.get)()) {
            const { outPath } = yield (0, enquirer_1.prompt)([
                {
                    type: 'input',
                    name: 'outPath',
                    message: 'What is the directory to store results in?',
                    initial: suggestion,
                    skip: !!((_b = config === null || config === void 0 ? void 0 : config.persist) === null || _b === void 0 ? void 0 : _b.outPath)
                }
            ]);
            suggestion = outPath;
        }
        // Check if path for output is given
        if (!suggestion) {
            throw new Error('Path to output folder is required. Either through the console as `--outPath` or in the `.user-flowrc.json`');
        }
        return Object.assign(Object.assign({}, config), { persist: Object.assign(Object.assign({}, config === null || config === void 0 ? void 0 : config.persist), { outPath: suggestion }) });
    });
}
exports.ensureOutPath = ensureOutPath;
function ensureUfPath(config) {
    var _a, _b;
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let suggestion = ((_a = config === null || config === void 0 ? void 0 : config.collect) === null || _a === void 0 ? void 0 : _a.ufPath) || constants_1.DEFAULT_COLLECT_UF_PATH;
        if ((0, interactive_1.get)()) {
            const { ufPath } = yield (0, enquirer_1.prompt)([
                {
                    type: 'input',
                    name: 'ufPath',
                    message: 'What is the directory provides the user-flows?',
                    initial: suggestion,
                    skip: !!((_b = config === null || config === void 0 ? void 0 : config.collect) === null || _b === void 0 ? void 0 : _b.ufPath)
                }
            ]);
            suggestion = ufPath;
        }
        // Check if path to user-flows is given
        if (!suggestion) {
            throw new Error('Path to user flows is required. Either through the console as `--ufPath` or in the `.user-flowrc.json`');
        }
        try {
            (0, fs_1.readdirSync)(suggestion);
        }
        catch (e) {
            (0, fs_1.mkdirSync)(suggestion);
        }
        return Object.assign(Object.assign({}, config), { collect: Object.assign(Object.assign({}, config === null || config === void 0 ? void 0 : config.collect), { ufPath: suggestion }) });
    });
}
exports.ensureUfPath = ensureUfPath;
function ensureUrl(config) {
    var _a, _b;
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let suggestion = ((_a = config === null || config === void 0 ? void 0 : config.collect) === null || _a === void 0 ? void 0 : _a.url) ? (_b = config === null || config === void 0 ? void 0 : config.collect) === null || _b === void 0 ? void 0 : _b.url.trim() : '';
        if ((0, interactive_1.get)()) {
            const { url } = yield (0, enquirer_1.prompt)([
                {
                    type: 'input',
                    name: 'url',
                    message: 'What is the URL to run the user flows for?',
                    initial: suggestion,
                    skip: suggestion !== ''
                }
            ]);
            suggestion = url || suggestion;
        }
        // Validate
        // Check if url is given
        if (suggestion === '' || suggestion === undefined) {
            throw new Error('URL is required. Either through the console as `--url` or in the `.user-flow.json`');
        }
        return Object.assign(Object.assign({}, config), { collect: Object.assign(Object.assign({}, config === null || config === void 0 ? void 0 : config.collect), { url: suggestion }) });
    });
}
exports.ensureUrl = ensureUrl;
/**
 * Takes the provided value form the cfg and evaluates it.
 * if CLI is interative it checks the given format and prompts the user if the value is not given
 * @param config
 */
function ensureFormat(config) {
    var _a;
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let suggestion = [];
        let cfgFormat = [];
        if ((_a = config === null || config === void 0 ? void 0 : config.persist) === null || _a === void 0 ? void 0 : _a.format) {
            cfgFormat = Array.isArray(config.persist.format) ? config.persist.format : [config.persist.format];
        }
        if (cfgFormat.length === 0) {
            suggestion = constats_1.REPORT_FORMAT_VALUES;
        }
        else {
            suggestion = cfgFormat;
        }
        if ((0, interactive_1.get)()) {
            const { format } = cfgFormat.length === 0 ? yield (0, enquirer_1.prompt)([
                {
                    type: 'multiselect',
                    name: 'format',
                    message: 'What is the format of user-flow reports? (use ⬇/⬆ to navigate, and SPACE key to select)',
                    choices: constats_1.REPORT_FORMAT_OPTIONS,
                    // @NOTICE typing is broken here
                    result(value) {
                        const values = value;
                        return values.map(name => { var _a; return ((_a = constats_1.REPORT_FORMAT_OPTIONS.find(i => i.name === name)) === null || _a === void 0 ? void 0 : _a.value) + ''; });
                    }
                }
            ]) : { format: cfgFormat };
            suggestion = format;
            if (suggestion.length === 0) {
                return ensureFormat(config);
            }
        }
        // Validate
        // Check if format is given
        if (!suggestion) {
            throw new Error('format is required. Either through the console as `--format` or in the `.user-flow.json`');
        }
        suggestion.forEach((val) => {
            if (!constats_1.REPORT_FORMAT_VALUES.find(i => i === val)) {
                throw new Error(`Wrong format "${val}" format has to be one of: ${constats_1.REPORT_FORMAT_VALUES.join(', ')}`);
            }
        });
        return Object.assign(Object.assign({}, config), { persist: Object.assign(Object.assign({}, config === null || config === void 0 ? void 0 : config.persist), { format: suggestion }) });
    });
}
exports.ensureFormat = ensureFormat;
//# sourceMappingURL=setup.js.map